#
# spec file for package python-debugpy
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor test%{nil}
%if "%{flavor}" == "test"
# multibuild: some tests fail to find modules in a custom PYTHONPATH, test installed instead
%define psuffix -test
%bcond_without test
%else
%define psuffix %{nil}
%bcond_with test
%endif
%{?sle15_python_module_pythons}
Name:           python-debugpy%{psuffix}
Version:        1.8.14
Release:        2.0.2.1.sr20250601
Summary:        An implementation of the Debug Adapter Protocol for Python
License:        MIT
URL:            https://github.com/microsoft/debugpy/
Source:         https://github.com/microsoft/debugpy/archive/v%{version}.tar.gz#/debugpy-%{version}.tar.gz
BuildRequires:  %{python_module Cython}
BuildRequires:  %{python_module devel >= 3.8}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  python-rpm-macros
%if %{with test}
BuildRequires:  %{python_module Flask}
BuildRequires:  %{python_module debugpy = %{version}}
BuildRequires:  %{python_module gevent}
BuildRequires:  %{python_module greenlet}
BuildRequires:  %{python_module psutil}
BuildRequires:  %{python_module pytest-timeout}
BuildRequires:  %{python_module pytest-xdist}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module requests}
BuildRequires:  gdb
%endif
Requires(post): alts
Requires(postun): alts
%python_subpackages

%description
debugpy is an implementation of the Debug Adapter Protocol for Python.

%prep
%autosetup -p1 -n debugpy-%{version}

# don't remove vendored pydevd: upstream's intention is to always bundle it. Development happens in debugpy anyway

# remove gitignore file
find src/debugpy/_vendored/pydevd/ -name .gitignore -delete
# remove a performance tweak not compatible with older gdb: https://github.com/microsoft/debugpy/issues/762
sed -i '/set auto-solib-add off/d' src/debugpy/_vendored/pydevd/pydevd_attach_to_process/add_code_to_python_process.py

%build
%if ! %{with test}
export CFLAGS='%{optflags}'
cp -r src/debugpy/_vendored src/debugpy/_vendored_clean
%{python_expand # cythonize and the attach library are compile in-place
# TODO: find out how to do it not-in-place
rm -r src/debugpy/_vendored
cp -r src/debugpy/_vendored_clean src/debugpy/_vendored
pushd src/debugpy/_vendored/pydevd/pydevd_attach_to_process/linux_and_mac/
# see /src/debugpy/_vendored/pydevd/pydevd_attach_to_process/add_code_to_python_process.py::get_target_filename
%{python_expand pyarch=$($python -c 'import platform; print(platform.machine())')}
g++ %{optflags} -shared -o ../attach_${pyarch}.so -fPIC -nostartfiles attach.cpp
# if on intel architectures, use the default upstream names
%ifarch x86_64
mv ../attach_${pyarch}.so ../attach_linux_amd64.so
%endif
%ifarch %ix86
mv ../attach_${pyarch}.so ../attach_linux_x86.so
%endif
popd
%pyproject_wheel
}
%endif

%install
%if !%{with test}
# Dont compile pydevd again
export SKIP_CYTHON_BUILD=1
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/debugpy
%python_clone -a %{buildroot}%{_bindir}/debugpy-adapter
%{python_expand # remove source files
rm -r %{buildroot}%{$python_sitearch}/debugpy/_vendored/pydevd/pydevd_attach_to_process/{common,linux_and_mac,windows}/
rm %{buildroot}%{$python_sitearch}/debugpy/_vendored/pydevd/_*/*.{c,h,pxd,pyx}
%fdupes %{buildroot}%{$python_sitearch}
}
%endif

%if %{with test}
%check
export DEBUGPY_TEST=1
export DEBUGPY_PROCESS_EXIT_TIMEOUT=30
export DEBUGPY_PROCESS_SPAWN_TIMEOUT=90
# extra flags are not added
donttest="test_custom_python_args"
rm -v tests/debugpy/test_django.py

# Disable broken tests in s390x, bsc#1217019
%ifarch s390x
sed -i "s/timeout=30/timeout=60/g" pytest.ini
donttest+=" or test_attach_api or test_reattach or test_break_api or test_set_variable or test_unicode or test_debugpySystemInfo or test_debug_this_thread or test_tracing"
%endif
# Attach-to-PID is not supported on ARM https://github.com/microsoft/debugpy/issues/1220
%ifarch aarch64
donttest+=" or test_reattach"
%endif

# Do not have numpy dependency
donttest+=" or test_numpy"
# Skip all attach_pid tests, it fails in OBS enviroment bsc#1219921
donttest+=" or attach_pid"

%pytest_arch -k "not ($donttest)"
%endif

%post
%python_install_alternative debugpy debugpy-adapter

%postun
%python_uninstall_alternative debugpy

%if ! %{with test}
%files %{python_files}
%{python_sitearch}/debugpy
%{python_sitearch}/debugpy-%{version}*-info
%python_alternative %{_bindir}/debugpy
%python_alternative %{_bindir}/debugpy-adapter
%endif

%changelog
* Thu Jun  5 2025 Steve Kowalik <steven.kowalik@suse.com>
- Switch to pyproject macros.
* Mon Apr 28 2025 Markéta Machová <mmachova@suse.com>
- Update to 1.8.14
  * fix ResourceWarning: unclosed socket
  * fix binskim warnings on linux
* Mon Feb 10 2025 Markéta Machová <mmachova@suse.com>
- Update to 1.8.12
  * To simplify command line usage, an debugpy entry point has been
    added to the debugpy package.
  * To simplify command line usage, switches can now be read from
    the environment.
  * Consuming PyDev.Debugger's sys.monitoring support to improve
    performance of debugging 3.12
  * Support for 3.13
  * Multithreading fixes
* Thu Sep 26 2024 Markéta Machová <mmachova@suse.com>
- Drop unneeded Django test dependency
- Skip one failing test on aarch64
* Sat Jun 29 2024 Dirk Müller <dmueller@suse.com>
- update to 1.8.2:
  * Fixed an issue where ApiScan couldn't scan some of our
    binaries correctly. This involved changing some linker flags
    and re-compiling/re-linking some of the pydevd executables
    and dlls.
* Thu Mar 28 2024 ecsos <ecsos@opensuse.org>
- Fix build error in Leap.
* Thu Feb 15 2024 Daniel Garcia <daniel.garcia@suse.com>
- Skip attach_pid tests that fails in OBS run environment bsc#1219921
* Wed Feb 14 2024 Daniel Garcia <daniel.garcia@suse.com>
- Update to 1.8.1:
  - Python 3.12 is now fully supported.
  - Fixes:
  - Can no longer expand Numpy arrays to view elements #1408
  - Namedtuple are not rendered in the variable browser as expected #1477
  - Enhancements:
  - Report sockets opened by debugpy #1337
* Mon Jan 29 2024 Daniel Garcia <daniel.garcia@suse.com>
- Disable broken tests in s390x, bsc#1217019
* Tue Dec  5 2023 Dirk Müller <dmueller@suse.com>
- remove python 3.6 support as the version update to 1.8.0 dropped
  it
* Mon Nov 20 2023 Daniel Garcia <daniel.garcia@suse.com>
- Increase timeouts for tests, bsc#1217019
* Fri Nov 17 2023 Matej Cepl <mcepl@cepl.eu>
- Update to 1.8.0:
  - Error while enumerating installed packages.
  - Drops Python 3.7 support. Please use debugpy v1.7.0 if you
    need to debug Python 3.7.
  - Remove DeprecationWarning: Deprecated call to
    pkg_resources.declare_namespace('pydevd_plugins.extensions')
  - Fix invalid file hashes in RECORD of wheels
  - Support "restart" in "terminated" event for "attach"{"listen"}
  - Use "startDebugging" request for subprocesses
- Remove upstreamed patch setuptools-67.3.0.patch
- Skip test test_attach_pid_client (gh#microsoft/debugpy#1462)
* Fri May 19 2023 Jiri Srain <jsrain@suse.com>
- refresh the tarball from upstream
* Thu Mar 16 2023 Daniel Garcia <daniel.garcia@suse.com>
- Add setuptools-67.3.0.patch to fix test issues with new setuptools.
  gh#microsoft/debugpy#1230
* Thu Feb  2 2023 Dirk Müller <dmueller@suse.com>
- skip more tests for python 3.11
* Mon Jan 23 2023 Dirk Müller <dmueller@suse.com>
- update to v1.6.6:
  * Disable optimization causing issues when debugging Python 3.10 and 3.11.
* Fri Jan 20 2023 Dirk Müller <dmueller@suse.com>
- update to v1.6.5:
  * Fixes: #1078, #1129, #1138, #1142, #1146, #1148, #1154
* Thu Dec  1 2022 Daniel Garcia <daniel.garcia@suse.com>
- Update to version 1.6.4
  Fixes: #985, #1003, #1005, #1018, #1024, #1025, #1030, #1031, #1042, #1064,
    [#1081], #1100, #1104, #1111, #1126
  Improvements: #532, #989, #1022, #1056, #1099
* Wed Oct 12 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 1.6.3
  Fixes: #869, #973, #987, #995, #1008
  Improvements: #951, #1001
* Mon Dec 20 2021 Ben Greiner <code@bnavigator.de>
- Update to 1.5.1
  * no release notes other than a bunch of github PR and issue
    numbers: https://github.com/microsoft/debugpy/releases
  * Python 3.10 is now fully supported
- Drop pydevd-openSUSE-attach-autoarch.patch, upstream changed
  architecture support logic
- Drop correct-pthread-library-name.patch merged upstream
- Remove performance tweak not compatible with older gdb
  * gh#microsoft/debugpy#762
* Thu Sep  2 2021 Steve Kowalik <steven.kowalik@suse.com>
- Add correct-pthread-library-name.patch:
  * Look for the correct pthread library.
* Tue Jun 29 2021 Ben Greiner <code@bnavigator.de>
- Update to 1.3.0
  * no release notes.
- new requirement for ipykernel 6
- enable testsuite (multibuild)
- defer debundling pydevd
- add pydevd-openSUSE-attach-autoarch.patch for support of
  non-intel architectures when injecting the debug library
- skip python36 in order to save resources
* Fri Dec  4 2020 Matej Cepl <mcepl@suse.com>
- Initial packaging of debugpy 1.2.0
